indicatortools.LilyPondCommand
==============================

.. abjad-lineage:: abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand

.. autoclass:: abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand.format_slot
      ~abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand.name
      ~abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand.__copy__
      ~abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand.__eq__
      ~abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand.__format__
      ~abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand.__ne__
      ~abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand.format_slot
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand.name
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand.__copy__
   :noindex:

.. automethod:: abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand.__eq__
   :noindex:

.. automethod:: abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand.__format__
   :noindex:

.. automethod:: abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand.__ne__
   :noindex:

.. automethod:: abjad.tools.indicatortools.LilyPondCommand.LilyPondCommand.__repr__
   :noindex:
